Fix comment to reflect that the value passed to head is actually the size

There is no functional change

Bug: 130257221
Test: generated an archive using the script and ran the result
Change-Id: I946f2827a9519873be2173fc50d9bc1cc46a326f
diff --git a/tools/generate-self-extracting-archive.py b/tools/generate-self-extracting-archive.py
index f1bade3..5b0628d 100755
--- a/tools/generate-self-extracting-archive.py
+++ b/tools/generate-self-extracting-archive.py
@@ -92,7 +92,7 @@
     dst.write(b)
 
 _MAX_OFFSET_WIDTH = 20
-def _generate_extract_command(start, end, extract_name):
+def _generate_extract_command(start, size, extract_name):
   """Generate the extract command.
 
   The length of this string must be constant no matter what the start and end
@@ -101,7 +101,7 @@
 
   Args:
     start: offset in bytes of the start of the wrapped file
     end: offset in bytes of the end of the wrapped file
     extract_name: of the file to create when extracted
 
   """
@@ -111,11 +111,11 @@
   if len(start_str) != _MAX_OFFSET_WIDTH + 1:
     raise Exception('Start offset too large (%d)' % start)
 
-  end_str = ('%d' % end).rjust(_MAX_OFFSET_WIDTH)
-  if len(end_str) != _MAX_OFFSET_WIDTH:
-    raise Exception('End offset too large (%d)' % end)
+  size_str = ('%d' % size).rjust(_MAX_OFFSET_WIDTH)
+  if len(size_str) != _MAX_OFFSET_WIDTH:
+    raise Exception('Size too large (%d)' % size)
 
-  return "tail -c %s $0 | head -c %s > %s\n" % (start_str, end_str, extract_name)
+  return "tail -c %s $0 | head -c %s > %s\n" % (start_str, size_str, extract_name)
 
 
 def main(argv):
@@ -101,7 +101,7 @@
   Args:
     start: offset in bytes of the start of the wrapped file
-    end: offset in bytes of the end of the wrapped file
+    size: size in bytes of the wrapped file
     extract_name: of the file to create when extracted
 